clear all
set matsize 11000
set maxvar 20000

** Name: Analysis.do
** Date Created: 02/20/2018 by Vincent Pons (vpons@hbs.edu)
** Last Updated: 05/29/2018

* Data In: [analysis & dropouts_press]

* Purpose of do-file: Generate tables and figures of paper and online appendix

* Organization :
/* 
*** PART I *** RESULTS IN THE MAIN TEXT
- PART I.A - Setting and empirical strategy
- PART I.B - Impact on participation
- PART I.C - Impact on the vote share of the top 2
- PART I.D - Impact on winner identity

*** PART II *** RESULTS IN THE APPENDIX
- PART II.A - Complementary tables and figures (Appendix A)
- PART II.B - Placebo tests (Appendix B)
- PART II.C - Robustness to 2 special cases (Appendix C)
- PART II.D - Campaign expenditures (Appendix D)
- PART II.E - Impact on the top two depending on the closeness (Appendix E)
- PART II.F - Impact on the top two depending on voters' level of information (Appendix F) 
- PART II.G - Dropouts - RDD (Appendix G)
- PART II.H - Dropouts - Press articles (Appendix H)
*/


* Setting file path
cd "${data}"

****************************************
****************************************
*** PART I *** RESULTS IN THE MAIN TEXT
****************************************

use "Analysis\analysis", clear

******************************************************************
*** PART I.A *** Setting and empirical Strategy (Sections 2 and 3)
******************************************************************

****************************************
*** Descriptive statistics (Section 2)
****************************************

** Number of elections where the third qualifies
tab assignment

** Threshold
tab threshold
tab threshold if year==2011

** Election types 
tab election_type

** Descriptive statistics (Table 1)
estpost sum nb_registered_R1 prop_registered_turnout_R1 prop_registered_candvotes_R1 prop_registered_blanknull_R1 nb_candidates_R1 prop_registered_turnout_R2  prop_registered_candvotes_R2 prop_registered_blanknull_R2 nb_candidates_R2 
esttab using "$paper\Table1_summary_statistics.tex", cells ("count mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))" ) replace 

** Number of candidates in the second round
tab nb_candidates_R2

** Orientation of the third candidate
tab political_orientation_cand3

** Vote share of the third candidate, round 2 
sum prop_voters_votes_cand3_R2 if treatment==1 & dropout_cand2==0
sum prop_voters_votes_cand2_R2 if treatment==1 & dropout_cand2==0
sum prop_voters_votes_cand1_R2 if treatment==1 & dropout_cand2==0

sum prop_voters_votes_cand3_R2 if treatment==1 & political_orientation_cand3=="left"  & dropout_cand2==0
sum prop_voters_votes_cand3_R2 if treatment==1 & political_orientation_cand3=="right" & dropout_cand2==0
sum prop_voters_votes_cand3_R2 if treatment==1 & political_orientation_cand3=="farright" & dropout_cand2==0

****************************************
*** Empirical strategy (Section 3)
****************************************

** Number of elections in a 2 percentage points bandwith
count if abs(running)<=0.02

** First stage

* Figure 1
rdplot treatment running, p(1) graph_options(title("") ytitle(Treatment status) xtitle(Running variable) graphregion(color(white)) legend(off) ylabel(0 (.2) 1) xlabel(-.1 (.05) .1))) nbins(20 20)
graph export "$paper\Figure1_1st_stage.pdf", replace 

* Table 1
* use the rdob command to compute Imbens and Kalyanaraman (IK)'s optimal bandwidths
* we then use the h_opt generated by the command to test the robustness of our results using these optimal bandwidths
rdob treatment running

rdrobust treatment running
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum treatment if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table2_1st_stage.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust treatment running, h(.03813415)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum treatment if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table2_1st_stage.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust treatment running, p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum treatment if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table2_1st_stage.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust treatment running, p(2) h(.03813415)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum treatment if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table2_1st_stage.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)


******************************************************
*** PART I.B *** Impact on participation (Section 4.1)
******************************************************

** Impact on turnout, blank and null votes and candidate votes (Figure 2)
rdplot prop_registered_turnout_R2 running, graph_options(title("") legend(off) ytitle(Turnout 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(.2(.2) 1) xlabel(-.15 (.05) .15))) p(2) nbins(30 30) 
graph export "$paper\Figure2_turnout.pdf", replace
rdplot prop_registered_blanknull_R2 running, graph_options(title("") legend(off) ytitle(Null and Blank votes 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(0(.2) .8) xlabel(-.15 (.05) .15)) p(2) nbins(30 30) 
graph export "$paper\Figure2_blanknull.pdf", replace
rdplot prop_registered_candvotes_R2 running, graph_options(title("") legend(off) ytitle(Candidate votes 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(.2(.2) 1) xlabel(-.15 (.05) .15))) p(2) nbins(30 30)
graph export "$paper\Figure2_candvotes.pdf", replace

** Impact on turnout, blank and null votes and candidate votes (Table 3)
rdrobust prop_registered_turnout_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_turnout_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table3_participation.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blanknull_R2 prop_registered_candvotes_R2 {
rdrobust `var' running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table3_participation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on candidate votes using different specifications (Table 4)
* use the rdob command to compute Imbens and Kalyanaraman (IK)'s optimal bandwidths
* we then use the h_opt generated by the command to test the robustness of our results using these optimal bandwidths
rdob prop_registered_candvotes_R2 running

rdrobust prop_registered_candvotes_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_candvotes_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table4_candvotes.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_candvotes_R2 running, fuzzy(treatment) h(.03690516) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_candvotes_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table4_candvotes.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_candvotes_R2 running running, fuzzy(treatment) p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_candvotes_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table4_candvotes.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_candvotes_R2 running running, fuzzy(treatment) h(.03690516)  p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_candvotes_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table4_candvotes.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)


********************************************************************
*** PART I.C *** Impact on the vote share of the top two candidates
********************************************************************

********************************************
*** Impact on the whole sample (Section 4.2)
********************************************

** Impact on the vote share of the top two candidates (Figure 3)
rdplot prop_registered_votes_top2_R2 running, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Top2 candidates 2nd round) graphregion(color(white)) xlabel(-.15 (.05) .15))))  p(2) nbins(30 30) 
graph export "$paper\Figure3_toptwo.pdf", replace

** Impact on the vote share of the top two candidates (Table 5)
* use the rdob command to compute Imbens and Kalyanaraman (IK)'s optimal bandwidths
* we then use the h_opt generated by the command to test the robustness of our results using these optimal bandwidths
rdob prop_registered_votes_top2_R2 running 

rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table5_toptwo.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) h(.0395407)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table5_toptwo.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table5_toptwo.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) h(.0395407) p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table5_toptwo.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

*******************************************************************************
*** Impact on the top two depending on political orientation (Section 4.3)
*******************************************************************************

** Statistics on the settings
tab sample0 if treatment==1 & abs(running)<=0.02

count if setting==1
count if farright_cand3==1 & ((right_cand1==1 & left_cand2==1) | (right_cand2==1 & left_cand1==1))
count if setting==2
count if left_cand3==1 & ((right_cand1==1 & farright_cand2==1) | (right_cand2==1 & farright_cand1==1))
count if setting==3
count if right_cand3==1 & ((left_cand1==1 & farright_cand2==1) | (left_cand2==1 & farright_cand1==1))
count if center_cand3==1 & ((left_cand1==1 & right_cand2==1) | (left_cand2==1 & right_cand1==1))

** Impact on the top two depending on political orientation (Figure 4)
* setting 1
rdplot prop_registered_votes_candA_R2 running if setting==1, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate A 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 15) 
graph export "$paper\Figure4_candA_setting1.pdf", replace
rdplot prop_registered_votes_candB_R2 running if setting==1, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate B 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 15) 
graph export "$paper\Figure4_candB_setting1.pdf", replace

* setting 2
rdplot prop_registered_votes_candB_R2 running if setting==2, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate B 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 15) 
graph export "$paper\Figure4_candB_setting2.pdf", replace
rdplot prop_registered_votes_candC_R2 running if setting==2, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate C 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 15) 
graph export "$paper\Figure4_candC_setting2.pdf", replace

* setting3
rdplot prop_registered_votes_candA_R2 running if setting==3, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate A 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 12) 
graph export "$paper\Figure4_candA_setting3.pdf", replace
rdplot prop_registered_votes_candC_R2 running if setting==3, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Candidate C 2nd round) ylabel(.2(.2) 1) graphregion(color(white)) xlabel(-.1 (.05) .1))))  p(2) nbins(26 12) 
graph export "$paper\Figure4_candC_setting3.pdf", replace

* impact on the difference between the vote shares of the top 2 in the three settings
rdrobust prop_reg_votes_diff_candAB running if setting==1, fuzzy(treatment) 
rdrobust prop_reg_votes_diff_candBC running if setting==2, fuzzy(treatment) 
rdrobust prop_reg_votes_diff_candAC running if setting==3, fuzzy(treatment) 

***************************************************************
*** Impact depending on the strength of the third (Section 4.4)
***************************************************************

** Impact depending on the strength of the third (Table 6)

** Statistics
foreach var in sample1 sample2 sample3 sample4 {
quietly rdrobust prop_registered_votes_top2_R2 running if `var'==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
dis `obs'
local bdw=e(h_l)
dis `bdw'
count if ranking_cand3_R2==1 & `var'==1 & running<=`bdw'
count if ranking_cand3_R2==2 & `var'==1 & running<=`bdw'
sum dist_strength_cand3_weakest_R1 if `var'==1 & abs(running)<=`bdw'
}

** Impact on the vote share of the top two
rdrobust prop_registered_votes_top2_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", replace addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", append addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", append addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", append addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if `i'==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", append addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if `i'==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$paper\Table6_toptwo_strength3rd.tex", append addstat("Robust p-value", e(pv_rb), Loc. Poly. (p),e(p), BW(h),e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

*********************************************************
*** PART I.D *** Impact on winner identity (Section 4.5)
*********************************************************

** Impact on winner identity (Figure 5)
rdplot winner_closest running if sample2==1, p(2) graph_options(title("") legend(off) xtitle(Running variable) ytitle(Closest cand wins) graphregion(color(white))ylabel(0 (.2) 1) xlabel(-.1(.05).1)) binselect(qs) nbins(15 15)
graph export "$paper\Figure5_winner_identity.pdf", replace

** Impact on winner identity (Table 7)
* use the rdob command to compute Imbens and Kalyanaraman (IK)'s optimal bandwidths
* we then use the h_opt generated by the command to test the robustness of our results using these optimal bandwidths
rdob winner_closest running if sample2==1

rdrobust winner_closest running if sample2==1, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if sample2==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table7_winner_identity.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust winner_closest running if sample2==1, fuzzy(treatment) h(.04269161)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if sample2==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table7_winner_identity.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust winner_closest running if sample2==1, fuzzy(treatment) p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if sample2==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table7_winner_identity.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust winner_closest running if sample2==1, fuzzy(treatment) p(2) h(.04269161)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if sample2==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$paper\Table7_winner_identity.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)


****************************************
****************************************
*** PART II *** RESULTS IN THE APPENDIX
****************************************

***************************************************************
*** PART II.A *** Complementary tables and figures (Appendix A)
***************************************************************

** Elections in the sample (Table A1)
tab year

** Mc Crary test (Figure A1)
set scheme s1mono
DCdensity running, breakpoint(0) generate(Xj Yj r0 fhat se_fhat)  
graph export "$appendix\FigureA1_McCrary.pdf", replace
drop Xj Yj r0 fhat se_fhat 
set scheme s2color

**  First round summary statistics on districts close to the threshold vs. fullsample (Table A2)
estpost sum nb_registered_R1 prop_registered_turnout_R1 prop_registered_candvotes_R1 prop_registered_blanknull_R1 nb_candidates_R1 prop_voters_votes_cand3_R1 prop_voters_votes_top2_R1
esttab using "$appendix\TableA2_summary_statistics.tex", cells ("count mean(fmt(3)) sd(fmt(3))" ) replace 

estpost sum nb_registered_R1 prop_registered_turnout_R1 prop_registered_candvotes_R1 prop_registered_blanknull_R1 nb_candidates_R1 prop_voters_votes_cand3_R1 prop_voters_votes_top2_R1 if abs(running)<=0.02
esttab using "$appendix\TableA2_summary_statistics.tex", cells ("count mean(fmt(3)) sd(fmt(3))" ) append

** ITT estimates when the third candidate has the same orientation as one top-two (Table A3)
rdrobust prop_registered_turnout_R2 running if third_same_orientation_top2==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_turnout_R2 if assignment==0 & abs(running)<=`bdw' & third_same_orientation_top2==1
local mean_control=r(mean)
outreg2 using "$appendix\TableA3_ITT_same_orientation.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blanknull_R2 prop_registered_candvotes_R2 prop_registered_votes_top2_R2 {
rdrobust `var' running if third_same_orientation_top2==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw' & third_same_orientation_top2==1
local mean_control=r(mean)
outreg2 using "$appendix\TableA3_ITT_same_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

rdrobust winner_closest running if sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if assignment==0 & abs(running)<=`bdw' & sample_same_orientation_closest==1
local mean_control=r(mean)
outreg2 using "$appendix\TableA3_ITT_same_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

** Impact on null and blank votes in 2015 local elections 
* Table A4
rdrobust prop_registered_blanknull_R2 running if year==2015, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_blanknull_R2 if year==2015 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA4_blanknull_2015.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blank_R2 prop_registered_null_R2{
rdrobust `var' running if year==2015, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if year==2015 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA4_blanknull_2015.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

* Figure A2
rdplot prop_registered_blanknull_R2 running if year==2015, graph_options(title("") legend(off) ytitle(Null and Blank votes 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(0 (.02) .1) xlabel(-.15 (.05) .15))) p(2) nbins(27 15) 
graph export "$appendix\FigureA2_blanknull_2015.pdf", replace
rdplot prop_registered_blank_R2 running if year==2015, graph_options(title("") legend(off) ytitle(Blank votes 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(0 (.02) .1) xlabel(-.15 (.05) .15)) p(2) nbins(27 15) 
graph export "$appendix\FigureA2_blank_2015.pdf", replace
rdplot prop_registered_null_R2 running if year==2015, graph_options(title("") legend(off) ytitle(Null votes 2nd round) xtitle(Running variable) graphregion(color(white)) ylabel(0 (.02) .1) xlabel(-.15 (.05) .15))) p(2) nbins(27 15) 
graph export "$appendix\FigureA2_null_2015.pdf", replace

** Impact on the vote share of the 1st and 2nd separately
* Table A5
rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA5_1st2nd.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_votes_cand1_R2 prop_registered_votes_cand2_R2 {
rdrobust `var' running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA5_1st2nd.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

* Figure A3
rdplot prop_registered_votes_cand1_R2 running, p(2) graph_options(legend(off) title("") xtitle(Running variable) ytitle(1st candidate 2nd round) graphregion(color(white)) ylabel(.2(.2) 1) xlabel(-.15 (.05) .15))))  p(2) nbins(30 30)  
graph export "$appendix\FigureA3_1stcand.pdf", replace
rdplot prop_registered_votes_cand2_R2 running, p(2) graph_options(legend(off) title("") xtitle(Running variable) ytitle(2nd candidate 2nd round) graphregion(color(white)) ylabel(.2(.2) 1) xlabel(-.15 (.05) .15))))  p(2) nbins(30 30)  
graph export "$appendix\FigureA3_2ndcand.pdf", replace

** Impact on the vote share of the top two depending on political orientation
* setting 1 (Table A6)
rdrobust prop_registered_votes_top2_R2 running if setting==1, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if setting==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA6_toptwo_setting1.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_votes_candA_R2 prop_registered_votes_candB_R2 {
rdrobust `var' running if setting==1, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if setting==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA6_toptwo_setting1.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

* setting 2 (Table A7)
rdrobust prop_registered_votes_top2_R2 running if setting==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if setting==2 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableA7_toptwo_setting2.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_votes_candB_R2 prop_registered_votes_candC_R2 {
rdrobust `var' running if setting==2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if setting==2 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA7_toptwo_setting2.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

* setting 3 (Table A8)
rdrobust prop_registered_votes_top2_R2 running if setting==3, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if setting==3 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA8_toptwo_setting3.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_votes_candA_R2 prop_registered_votes_candC_R2 {
rdrobust `var' running if setting==3, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if setting==3 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA8_toptwo_setting3.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the victory margin
* Table A9
rdrobust distance_voteshare_winner2nd_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum distance_voteshare_winner2nd_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA9_winning_margin.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

* Figure A4
rdplot distance_voteshare_winner2nd_R2 running, fuzzy(treatment) graph_options(legend(off) title("") ytitle(Distance Winner-2nd 2nd round) xtitle(Running variable) graphregion(color(white)) xlabel(-.15 (.05) .15))) p(2) nbins(30 30) 
graph export "$appendix\FigureA4_winning_margin.pdf", replace

** Impact on the victory margin depending on the orientations of the top two (Table A10)
rdrobust distance_voteshare_winner2nd_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum distance_voteshare_winner2nd_R2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableA10_winmargin_orientation.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust distance_voteshare_winner2nd_R2 running if political_orientation_cand1==political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum distance_voteshare_winner2nd_R2 if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1==political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA10_winmargin_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust distance_voteshare_winner2nd_R2 running if political_orientation_cand1!=political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum distance_voteshare_winner2nd_R2 if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1!=political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA10_winmargin_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

** Impact on participation depending on the orientations of the top two (Table A11)
rdrobust prop_registered_turnout_R2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_turnout_R2 if assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blanknull_R2 prop_registered_candvotes_R2 {
rdrobust `var' running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

rdrobust prop_registered_turnout_R2 running if political_orientation_cand1==political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_turnout_R2 if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1==political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blanknull_R2 prop_registered_candvotes_R2 {
rdrobust `var' running if political_orientation_cand1==political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1==political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

rdrobust prop_registered_turnout_R2 running if political_orientation_cand1!=political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_turnout_R2 if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1!=political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in prop_registered_blanknull_R2 prop_registered_candvotes_R2 {
rdrobust `var' running if political_orientation_cand1!=political_orientation_cand2, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw' & political_orientation_cand1!=political_orientation_cand2
local mean_control=r(mean)
outreg2 using "$appendix\TableA11_participation_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Robustness of the main results to bandwidth choice (Figure A5)

** Candidate votes
forvalues j=1/2 {
clear
* local and matrix initialization
local bw_min	0.012
local bw_max 	0.1
local bw_gap 	0.002
local n_cols 	4
local col_bw 	1
local col_tau 	2
local col_CI_l	3
local col_CI_r 	4
mat results = J(1, `n_cols', 0)
mat colnames results = "bw tau CI_l CI_r"
mat row = J(1, `n_cols', 0)
* run and store estimates
use "Analysis\analysis"
rdrobust prop_registered_candvotes_R2 running, h(0.01) fuzzy(treatment) p(`j')
local bw_initial = e(h_l)
mat results[1, `col_bw'] 	= `bw_initial'
mat results[1, `col_tau'] 	= e(tau_cl)
mat results[1, `col_CI_l']  = e(ci_l_rb)
mat results[1, `col_CI_r']	= e(ci_r_rb)
forvalues bw = `bw_min'(`bw_gap')`bw_max' {
	rdrobust prop_registered_candvotes_R2 running, fuzzy(treatment) h(`bw') p(`j')
	mat row[1, `col_bw'] 	= `bw'
	mat row[1, `col_tau'] 	= e(tau_cl)
	mat row[1, `col_CI_l']	= e(ci_l_rb)
	mat row[1, `col_CI_r']	= e(ci_r_rb)
	mat results = results \ row
}
* draw estimates and CIs
clear
use "Analysis\analysis"
quietly rdrobust prop_registered_candvotes_R2 running, fuzzy(treatment) p(`j')
local bdw_CCT=e(h_l)
rdob prop_registered_candvotes_R2 running
local bdw_IK=.03690516
svmat results, names(col)
twoway	(scatter CI_l bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter CI_r bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter tau bw, mcolor(gs6) sort(bw)), xline(`bdw_CCT', lcolor(red)) xline(`bdw_IK', lcolor(blue)) ///
		xlabel (.01(.01).1) ylabel (0 (.1) .5) title(Candidate votes - Poly. Order `j') ytitle(Treatment effect - Candidate votes) xtitle(Bandwidth) ///
		graphregion(fcolor(white) lcolor(white) margin(zero)) legend(off)
graph export "$appendix\FigureA5_bdwp`j'_candvotes.pdf", replace
mata: mata clear
}

** Vote share top2
forvalues j=1/2 {
clear
* local and matrix initialization
local bw_min	0.012
local bw_max 	0.1
local bw_gap 	0.002
local n_cols 	4
local col_bw 	1
local col_tau 	2
local col_CI_l	3
local col_CI_r 	4
mat results = J(1, `n_cols', 0)
mat colnames results = "bw tau CI_l CI_r"
mat row = J(1, `n_cols', 0)
* run and store estimates
use "Analysis\analysis"
rdrobust prop_registered_votes_top2_R2 running, h(0.01) fuzzy(treatment) p(`j')
local bw_initial = e(h_l)
mat results[1, `col_bw'] 	= `bw_initial'
mat results[1, `col_tau'] 	= e(tau_cl)
mat results[1, `col_CI_l']  = e(ci_l_rb)
mat results[1, `col_CI_r']	= e(ci_r_rb)
forvalues bw = `bw_min'(`bw_gap')`bw_max' {
	rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) h(`bw') p(`j')
	mat row[1, `col_bw'] 	= `bw'
	mat row[1, `col_tau'] 	= e(tau_cl)
	mat row[1, `col_CI_l']	= e(ci_l_rb)
	mat row[1, `col_CI_r']	= e(ci_r_rb)
	mat results = results \ row
}
* draw estimates and CIs
clear
use "Analysis\analysis"
quietly rdrobust prop_registered_votes_top2_R2 running, fuzzy(treatment) p(`j')
local bdw_CCT=e(h_l)
rdob prop_registered_votes_top2_R2 running
local bdw_IK=.0395407
svmat results, names(col)
twoway	(scatter CI_l bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter CI_r bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter tau bw, mcolor(gs6) sort(bw)), xline(`bdw_CCT', lcolor(red)) xline(`bdw_IK', lcolor(blue)) ///
		xlabel(.01(.01).1) ylabel(-.3 (.1) .2) title(Vote share top two - Poly. Order `j') ytitle(Treatment effect - Vote share top two) xtitle(Bandwidth) ///
		graphregion(fcolor(white) lcolor(white) margin(zero)) legend(off)
graph export "$appendix\FigureA5_bdwp`j'_top2.pdf", replace
mata: mata clear
}

** Winner identity
forvalues j=1/2 {
clear
* local and matrix initialization
local bw_min	0.012
local bw_max 	0.1
local bw_gap 	0.002
local n_cols 	4
local col_bw 	1
local col_tau 	2
local col_CI_l	3
local col_CI_r 	4
mat results = J(1, `n_cols', 0)
mat colnames results = "bw tau CI_l CI_r"
mat row = J(1, `n_cols', 0)
* run and store estimates
use "Analysis\analysis"
rdrobust winner_closest running if sample2==1, h(0.01) fuzzy(treatment) p(`j')
local bw_initial = e(h_l)
mat results[1, `col_bw'] 	= `bw_initial'
mat results[1, `col_tau'] 	= e(tau_cl)
mat results[1, `col_CI_l']  = e(ci_l_rb)
mat results[1, `col_CI_r']	= e(ci_r_rb)
forvalues bw = `bw_min'(`bw_gap')`bw_max' {
	rdrobust winner_closest running if sample2==1, fuzzy(treatment) h(`bw') p(`j')
	mat row[1, `col_bw'] 	= `bw'
	mat row[1, `col_tau'] 	= e(tau_cl)
	mat row[1, `col_CI_l']	= e(ci_l_rb)
	mat row[1, `col_CI_r']	= e(ci_r_rb)
	mat results = results \ row
}
* draw estimates and CIs
clear
use "Analysis\analysis"
quietly rdrobust winner_closest running if sample2==1, fuzzy(treatment) p(`j')
local bdw_CCT=e(h_l)
rdob winner_closest running if sample2==1
local bdw_IK=.04269161
svmat results, names(col)
twoway	(scatter CI_l bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter CI_r bw, lcolor(gs8) lpattern(shortdash) recast(line)) ///
		(scatter tau bw, mcolor(gs6) sort(bw)), xline(`bdw_CCT', lcolor(red)) xline(`bdw_IK', lcolor(blue)) ///
		xlabel(.01(.01).1) ylabel(-.6 (.2) .4) title(Closest cand wins - Poly. Order `j') ytitle(Treatment effect - Closest cand wins) xtitle(Bandwidth) ///
		graphregion(fcolor(white) lcolor(white) margin(zero)) legend(off)
graph export "$appendix\FigureA5_bdwp`j'_winner.pdf", replace
mata: mata clear
}

*********************************************************
*** PART II.B *** Placebo tests (Appendix B)
*********************************************************
clear
use "Analysis\analysis"

** Impact on baseline variables (Figure B1)
rdplot prop_registered_turnout_R1 running,graph_options(legend(off) title("") ytitle(Turnout 1st round) xtitle(Running variable) graphregion(color(white))) p(2) xlabel(-.15 (.05) .15)) nbins(30 30) 
graph export "$appendix\FigureB1_turnoutR1.pdf", replace
rdplot nb_registered_R1 running,graph_options(legend(off) title("") ytitle(Number of registered citizens) xtitle(Running variable) graphregion(color(white))) p(2) xlabel(-.15 (.05) .15)) nbins(30 30)  
graph export "$appendix\FigureB1_registered.pdf", replace
rdplot nb_candidates_R1 running, graph_options(legend(off) title("") ytitle(Number of candidates 1st round) xtitle(Running variable) graphregion(color(white))) p(2) xlabel(-.15 (.05) .15)) nbins(30 30)  
graph export "$appendix\FigureB1_nbcandidatesR1.pdf", replace
rdplot distance_voteshare_cand12_R1 running, graph_options(legend(off) title("") ytitle(Distance 1st-2nd 1st round) xtitle(Running variable) graphregion(color(white))) p(2) xlabel(-.15 (.05) .15)) nbins(30 30)  
graph export "$appendix\FigureB1_closenessR1.pdf", replace

** Impact on baseline variables and predicted assignment (Table B1)
rdrobust nb_registered_R1 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum nb_registered_R1 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableB1_placebo.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs', "Outcome mean", `mean_control') noobs noaster nonotes dec(3) adec(3) sdec(3)

foreach var in nb_candidates_R1 prop_registered_turnout_R1 distance_voteshare_cand12_R1 predicted_assignment {
rdrobust `var' running, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `var' if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableB1_placebo.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on predicted assignment (Figure B2)
rdplot predicted_assignment running, graph_options(legend(off) title("") ytitle(Predicted assignment value) xtitle(Running variable) graphregion(color(white))) p(2) nbins(30 30) xlabel(-.15 (.05) .15)) 
graph export "$appendix\FigureB2_predicted_assignment.pdf", replace


************************************************************
*** PART II.C *** Robustness to 2 special cases (Appendix C)
************************************************************

*** 2nd candidate dropouts (Case 1)

** Statistics
tab dropout_cand2 if abs(running)<=0.02
tab treatment if dropout_cand2==1 & assignment==1 & abs(running)<=0.02

** Impact on 2nd candidate dropouts (Table C1)
* use the rdob command to compute Imbens and Kalyanaraman (IK)'s optimal bandwidths
* we then use the h_opt generated by the command to test the robustness of our results using these optimal bandwidths
rdob dropout_cand2 running

rdrobust dropout_cand2 running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableC1_dropout_2ndcand.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust dropout_cand2 running, fuzzy(treatment) h(.03668774)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableC1_dropout_2ndcand.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust dropout_cand2 running, fuzzy(treatment) p(2)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableC1_dropout_2ndcand.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust dropout_cand2 running, fuzzy(treatment) p(2) h(.03668774)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand2 if assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableC1_dropout_2ndcand.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

*** 4th candidate qualifies (Case 2)

** Statistics
count if abs(running)<=0.02
count if prop_registered_votes_cand4_R1>=threshold & prop_registered_votes_cand4_R1!=. & abs(running)<=0.02
count if prop_registered_votes_cand4_R1>=threshold & prop_registered_votes_cand4_R1!=. & prop_registered_votes_cand4_R2!=. & abs(running)<=0.02
tab dropout_cand3 if prop_registered_votes_cand4_R1>=threshold & prop_registered_votes_cand4_R1!=. & prop_registered_votes_cand4_R2!=. & abs(running)<=0.02
sum prop_registered_turnout_R1 if prop_registered_votes_cand4_R1>=threshold & prop_registered_votes_cand4_R1!=.
count if prop_registered_votes_cand4_R1>=threshold & prop_registered_votes_cand4_R1!=. & prop_registered_turnout_R1<0.58

** Impact when turnout in the 1st round < 58% (Table C2)
rdrobust prop_registered_candvotes_R2 running if prop_registered_turnout_R1<=0.58, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_candvotes_R2 if prop_registered_turnout_R1<=0.58 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableC2_4th_not_qualified.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running if prop_registered_turnout_R1<=0.58, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if prop_registered_turnout_R1<=0.58 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableC2_4th_not_qualified.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust winner_closest running if sample2==1 & prop_registered_turnout_R1<=0.58, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum winner_closest if sample2==1 & prop_registered_turnout_R1<=0.58 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableC2_4th_not_qualified.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)


*********************************************************
*** PART II.D *** Campaign expenditures (Appendix D)
*********************************************************

** Number of elections for which we have data on campaign expenditures of the top 3
count if tot_expenditures_cand1!=.

** Impact on the top two's campaign expenditures (Figure D1) 
rdplot tot_expenditures_top2_reg running if id_unique!=1975011997, p(2) graph_options(legend(off) graphregion(color(white)) title("") xtitle(Running variable) ytitle(Top 2 Expenditures) ylabel(0.8(.2)1.6) xlabel(-.1(.05).1))  nbins(30 15)
Graph export "$appendix\FigureD1_expenditures_top2.pdf", replace
rdplot tot_contributions_top2_reg running if id_unique!=1975011997, p(2) graph_options(legend(off) graphregion(color(white)) title("") xtitle(Running variable) ytitle(Top 2 Contributions) xlabel(-.1(.05).1) ylabel(0.8(.2)1.6)) nbins(30 15)
Graph export "$appendix\FigureD1_contributions_top2.pdf", replace

** Impact on the top two's campaign expenditures (Table D1) 
quietly rdrobust tot_expenditures_top2_reg running, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum tot_expenditures_top2_reg if  assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
quietly outreg2 using "$appendix\TableD1_campaign_top2.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach j in tot_contributions personal_contributions party_contributions natural_advantages donations other_contributions acccount_balance {
quietly rdrobust `j'_top2_reg  running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `j'_top2_reg  if  assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
quietly outreg2 using "$appendix\TableD1_campaign_top2.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the third candidate's campaign expenditures (Figure D2) 
rdplot tot_expenditures_cand3_reg running if id_unique!=1975011997, p(2) graph_options(legend(off) graphregion(color(white)) title("") xtitle(Running variable) ytitle(3rd Expenditures) xlabel(-.1(.05).1) ylabel(0(.1).5)) nbins(30 15)
Graph export "$appendix\FigureD2_expenditures_cand3.pdf", replace
rdplot tot_contributions_cand3_reg running if id_unique!=1975011997, p(2) graph_options(legend(off) graphregion(color(white)) title("") xtitle(Running variable) ytitle(3rd Contributions) xlabel(-.1(.05).1) ylabel(0(.1).5)) nbins(30 15)
Graph export "$appendix\FigureD2_contributions_cand3.pdf", replace

** Impact on the third candidate's campaign expenditures (Table D2) 
quietly rdrobust tot_expenditures_cand3_reg running, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum tot_expenditures_cand3_reg if  assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
quietly outreg2 using "$appendix\TableD2_campaign_cand3.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach j in tot_contributions personal_contributions party_contributions natural_advantages donations other_contributions acccount_balance {
quietly rdrobust `j'_cand3_reg  running, fuzzy(treatment) 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum `j'_cand3_reg  if  assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
quietly outreg2 using "$appendix\TableD2_campaign_cand3.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}


*******************************************************************************
*** PART II.E *** Impact on the top two depending on the closeness (Appendix E)
*******************************************************************************

** Statistics
sum distance_voteshare_cand12_R1 if sample1==1 & distance_voteshare_cand12_R1<=0.1 & abs(running)<=0.02
sum distance_voteshare_cand12_R1 if sample1==1 & distance_voteshare_cand12_R1<=0.05 & abs(running)<=0.02
sum distance_strength_cand12_R1 if sample1==1 & distance_strength_cand12_R1<=0.1 & abs(running)<=0.02
sum distance_strength_cand12_R1 if sample1==1 & distance_strength_cand12_R1<=0.05 & abs(running)<=0.02

** Impact depending on the closeness in vote shares (Table E1)
rdrobust prop_registered_votes_top2_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if sample1==1 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if sample1==1 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE1_closeness_voteshare.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact depending on the closeness in strengths (Table E2)
rdrobust prop_registered_votes_top2_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if sample1==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_closest_R2 running if sample1==1 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
rdrobust prop_reg_votes_furthest_R2 running if sample1==1 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
outreg2 using "$appendix\TableE2_closeness_strength.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l)) addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

* robustness to using elections of sample 2
rdrobust prop_registered_votes_top2_R2 running if sample2==1, fuzzy(treatment)
rdrobust prop_reg_votes_closest_R2 running if sample2==1, fuzzy(treatment)
rdrobust prop_reg_votes_furthest_R2 running if sample2==1, fuzzy(treatment)
foreach var in voteshare strength {
foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample2==1 & distance_`var'_cand12_R1<=`i', fuzzy(treatment)
rdrobust prop_reg_votes_closest_R2 running if sample2==1 & distance_`var'_cand12_R1<=`i', fuzzy(treatment)
rdrobust prop_reg_votes_furthest_R2 running if sample2==1 & distance_`var'_cand12_R1<=`i', fuzzy(treatment)
}
}


***********************************************************************************************
*** PART II.F *** Impact on the top two depending on voters' level of information (Appendix F)
***********************************************************************************************

*************************************
*** Salience
**************************************

** Impact on the top two in local vs. parliamentary elections (Table F1)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF1_top2_salience.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==1
local mean_control=r(mean) 
outreg2 using "$appendix\TableF1_top2_salience.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

** Impact on the top two depending on the distance between the third and the top two, in parliamentary elections (Table F2)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==1
local mean_control=r(mean) 
outreg2 using "$appendix\TableF2_strength_parliamentary.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & election_type==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & `i'==1 & election_type==1 
local mean_control=r(mean) 
outreg2 using "$appendix\TableF2_strength_parliamentary.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the closeness of the race, in parliamentary elections (Table F3)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==1
local mean_control=r(mean) 
outreg2 using "$appendix\TableF3_closeness_parliamentary.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==1 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==1 & distance_voteshare_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF3_closeness_parliamentary.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & election_type==1 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & election_type==1 & distance_strength_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF3_closeness_parliamentary.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

*************************************
*** Media exposure
*************************************

** Statistics
dis _N
count if dpt_newspaper_circulation!=.
count if dpt_radio_audience!=.
count if region_TV_audience!=.

** Impact on the top two in districts above vs. below the median (Table F4)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==1
local mean_control=r(mean) 
outreg2 using "$appendix\TableF4_top2_median.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF4_top2_median.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in radio TV {
forvalues i=1/2 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_`var'==`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_`var'==`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF4_top2_median.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}
}

** Impact on the top two in districts in different terciles (Table F5)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_newspaper==1, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & terciles_newspaper==1
local mean_control=r(mean) 
outreg2 using "$appendix\TableF5_top2_terciles.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_newspaper==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & terciles_newspaper==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF5_top2_terciles.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_newspaper==3, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & terciles_newspaper==3
local mean_control=r(mean) 
outreg2 using "$appendix\TableF5_top2_terciles.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach var in radio TV {
forvalues i=1/3 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_`var'==`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & terciles_`var'==`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF5_top2_terciles.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}
}

** Impact on the top two depending on the distance between the third and the top two, in districts with newspaper circulation above the median (Table F6)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF6_strength_median_newspaper.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & median_newspaper==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & `i'==1 & median_newspaper==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF6_strength_median_newspaper.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the distance between the third and the top two, in districts with radio audience above the median (Table F6)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_radio==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_radio==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF7_strength_median_radio.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & median_radio==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & `i'==1 & median_radio==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF7_strength_median_radio.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the distance between the third and the top two, in districts with TV audience above the median (Table F6)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_TV==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_TV==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF8_strength_median_TV.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & median_TV==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & `i'==1 & median_TV==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF8_strength_median_TV.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the closeness of the race, in districts with newspaper circulation above the median (Table F9)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF9_closeness_median_newspaper.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==2 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==2 & distance_voteshare_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF9_closeness_median_newspaper.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_newspaper==2 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_newspaper==2 & distance_strength_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF9_closeness_median_newspaper.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the closeness of the race, in districts with radio audience above the median (Table F9)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_radio==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_radio==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF10_closeness_median_radio.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_radio==2 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_radio==2 & distance_voteshare_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF10_closeness_median_radio.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_radio==2 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_radio==2 & distance_strength_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF10_closeness_median_radio.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the top two depending on the closeness of the race, in districts with TV audience above the median (Table F9)
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_TV==2, fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_TV==2
local mean_control=r(mean) 
outreg2 using "$appendix\TableF11_closeness_median_TV.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_TV==2 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_TV==2 & distance_voteshare_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF11_closeness_median_TV.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & median_TV==2 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum prop_registered_votes_top2_R2 if assignment==0 & abs(running)<=`bdw' & sample1==1 & median_TV==2 & distance_strength_cand12_R1<=`i'
local mean_control=r(mean) 
outreg2 using "$appendix\TableF11_closeness_median_TV.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Robustness of the subsample analysis to using distritcs in the third terciles
* distance
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_newspaper==3, fuzzy(treatment)
foreach i in sample2 sample3 {
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & terciles_newspaper==3, fuzzy(treatment)
}
* we force the bandwidth for the last estimation, using the bandwidth of the previous estimation
rdrobust prop_registered_votes_top2_R2 running if sample3==1 & terciles_newspaper==3, fuzzy(treatment) 
local bdw=e(h_l)
rdrobust prop_registered_votes_top2_R2 running if sample4==1 & terciles_newspaper==3, fuzzy(treatment) h(`bdw')

foreach var in radio TV {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_`var'==3, fuzzy(treatment)
foreach i in sample2 sample3 sample4{
rdrobust prop_registered_votes_top2_R2 running if `i'==1 & terciles_`var'==3, fuzzy(treatment)
}
}
* closeness
foreach var in newspaper radio TV {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_`var'==3, fuzzy(treatment)
foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_`var'==3 & distance_voteshare_cand12_R1<=`i', fuzzy(treatment)
}
foreach i in 0.1 0.05 {
rdrobust prop_registered_votes_top2_R2 running if sample1==1 & terciles_`var'==3 & distance_strength_cand12_R1<=`i', fuzzy(treatment)
}
}


*********************************************************
*** PART II.G *** Dropouts - RDD (Appendix G)
*********************************************************

** Impact on the third candidate's dropout depending on her orientation (Figure G1)
rdplot dropout_cand3 running, p(1) graph_options(title("Full Sample") ytitle(3rd candidate drops out) xtitle(Running variable) legend(off) graphregion(color(white)) ylabel(0 (.2) 1) xlabel(-.1 (.05) .1))) nbins(1 20) 
Graph export "$appendix\FigureG1_dropout3rd.pdf", replace
rdplot dropout_cand3 running if third_same_orientation_top2==1, p(1) graph_options(title("3rd candidate has the same orientation as one top-two") ytitle(3rd candidate drops out) xtitle(Running variable) legend(off) graphregion(color(white)) ylabel(0 (.2) 1) xlabel(-.1 (.05) .1))) nbins(20 20)  
Graph export "$appendix\FigureG1_dropout3rd_same.pdf", replace
rdplot dropout_cand3 running if third_same_orientation_top2==0, p(1) graph_options(title("3rd candidate has a different orientation") ytitle(3rd candidate drops out) xtitle(Running variable) legend(off) graphregion(color(white)) ylabel(0 (.2) 1) xlabel(-.1 (.05) .1))) nbins(20 20)  
Graph export "$appendix\FigureG1_dropout3rd_different.pdf", replace

** Impact on the third candidate's dropout depending on her orientation (Table G1)
rdrobust dropout_cand3 running
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if  assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableG1_dropout3rd_orientation.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 1 0{
rdrobust dropout_cand3 running if third_same_orientation_top2==`i'
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if third_same_orientation_top2==`i' & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean) 
outreg2 using "$appendix\TableG1_dropout3rd_orientation.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the third candidate's dropout depending on the closeness of the race, same orientation (Table G2)
rdrobust dropout_cand3 running if sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample_same_orientation_closest==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableG2_dropout3rd_closeness_same.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust dropout_cand3 running if distance_voteshare_cand12_R1<=`i' & sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if distance_voteshare_cand12_R1<=`i' & sample_same_orientation_closest==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableG2_dropout3rd_closeness_same.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

rdrobust dropout_cand3 running if distance_strength_cand12_R1<=0.1 & sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if distance_strength_cand12_R1<=0.1 & sample_same_orientation_closest==1 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean)
outreg2 using "$appendix\TableG2_dropout3rd_closeness_same.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

* we force the bandwidth for the last estimation, using the bandwidth of the previous estimation
rdrobust dropout_cand3 running if distance_strength_cand12_R1<=0.1 & sample_same_orientation_closest==1
local bdw_temp=e(h_l)
rdrobust dropout_cand3 running if distance_strength_cand12_R1<=0.05 & sample_same_orientation_closest==1, h(`bdw_temp')
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if distance_strength_cand12_R1<=0.05 & sample_same_orientation_closest==1 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean)
outreg2 using "$appendix\TableG2_dropout3rd_closeness_same.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

** Impact on the third candidate's dropout depending on the closeness of the race, different orientation (Table G3)
rdrobust dropout_cand3 running if sample1==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample1==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableG3_dropout3rd_closeness_different.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

foreach i in 0.1 0.05 {
rdrobust dropout_cand3 running if distance_voteshare_cand12_R1<=`i' & sample1==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if distance_voteshare_cand12_R1<=`i' & sample1==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableG3_dropout3rd_closeness_different.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

foreach i in 0.1 0.05 {
rdrobust dropout_cand3 running if distance_strength_cand12_R1<=`i' & sample1==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if distance_strength_cand12_R1<=`i' & sample1==1 & assignment==0 & abs(running)<=`bdw'
local mean_control=r(mean)
outreg2 using "$appendix\TableG3_dropout3rd_closeness_different.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

** Impact on the third candidate's dropout depending on her distance with the top two, same orientation (Table G4)
rdrobust dropout_cand3 running if sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample_same_orientation_closest==1 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean) 
outreg2 using "$appendix\TableG4_dropout3rd_distancetop2_same.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

rdrobust dropout_cand3 running if (prop_voters_votes_cand2_R1-prop_voters_votes_cand3_R1)>=0.05 & sample_same_orientation_closest==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample_same_orientation_closest==1 & (prop_voters_votes_cand2_R1-prop_voters_votes_cand3_R1)>=0.05 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean) 
outreg2 using "$appendix\TableG4_dropout3rd_distancetop2_same.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

* we force the bandwidth for the last estimation, using the bandwdith of the previous estimation
rdrobust dropout_cand3 running if (prop_voters_votes_cand2_R1-prop_voters_votes_cand3_R1)>=0.05 & sample_same_orientation_closest==1
local bdw_temp=e(h_l)
rdrobust dropout_cand3 running if (prop_voters_votes_cand2_R1-prop_voters_votes_cand3_R1)>=0.1 & sample_same_orientation_closest==1, h(`bdw_temp')
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample_same_orientation_closest==1 & (prop_voters_votes_cand2_R1-prop_voters_votes_cand3_R1)>=0.1 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean) 
outreg2 using "$appendix\TableG4_dropout3rd_distancetop2_same.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)

** Impact on the third candidate's dropout depending on her distance with the top two, different orientation (Table G5)
rdrobust dropout_cand3 running if sample1==1
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if sample1==1 & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean) 
outreg2 using "$appendix\TableG5_dropout3rd_distancetop2_different.tex", replace addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
foreach j in sample3 sample4 {
rdrobust dropout_cand3 running if `j'==1 
local obs=e(N_h_l)+e(N_h_r)
local bdw=e(h_l)
sum dropout_cand3 if `j'==1  & assignment==0 & abs(running)<=`bdw' 
local mean_control=r(mean) 
outreg2 using "$appendix\TableG5_dropout3rd_distancetop2_different.tex", append addstat("Robust p-value", e(pv_rb), "Polyn. order",e(p), "Bandwidth",e(h_l), "Outcome mean", `mean_control') addtext(Observations, `obs') noobs noaster nonotes adec(3) bdec(3) sdec(3)
}

*********************************************************
*** PART II.H *** Dropouts - Press articles (Appendix H)
*********************************************************
clear

use "Analysis\dropouts_press", clear

** Descriptive Statistics (Table H2)
foreach var in national_level departement_level district_level {
tab `var'
}

tab third_same_orientation_top2 
count if third_same_orientation_top2==.

** Statistics on the dropout's context, reasons and reactions (Table H3)
* context
foreach var in existence_context context_party_decision context_agreement context_individual_decision {
tab `var' 
bysort third_same_orientation_top2: tab `var' 
}
* reasons
foreach var in existence_reason reason_prevent_victory reason_ideo_proximity other_reason {
tab `var' 
bysort third_same_orientation_top2: tab `var' 
}
* reactions
foreach var in existence_reaction reaction_exclusion reaction_voters reaction_furthest_party other_reaction {
tab `var' 
bysort third_same_orientation_top2: tab `var' 
}




